# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-04-29 11:00:52
:LastEditTime: 2022-05-24 20:42:21
:LastEditors: ChenXiaolei
:Description: 文件上传信息
"""
from PIL import Image
from io import BytesIO
from seven_studio.libs.file.ks3 import *
from seven_studio.libs.file.oss2 import *
from seven_studio.libs.file.cos import *
from seven_studio.libs.file.bos import *
from seven_studio.libs.file.s3 import *
from seven_studio.utils.random import *
from seven_framework.time import *
from seven_framework.uuid import *
from seven_framework.crypto import *

from seven_studio.models.seven_model import InvokeResult
from seven_studio.models.seven_model import FileUploadInfo
from seven_studio.models.enum import AccessModeCodeType
from seven_studio.models.db_models.file.file_storage_path_model import *
from seven_studio.models.db_models.file.file_restrict_model import *
from seven_studio.models.db_models.file.file_history_model import *


class FileUpload():
    """
    :description: 文件相关操作类
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    def __init__(self, file_context_key='db_sevenstudio'):
        self.file_context_key = file_context_key

    def upload(self, resource_code, restrict_code, dict_file):
        """
        :description: 文件上传
        :param resource_code：资源代码
        :param restrict_code：资源限制码
        :param dict_file：字典文件信息
        :return: InvokeResult
        :last_editors: HuangJingCan
        """
        invoke_result = InvokeResult()

        if resource_code == "" or restrict_code == "":
            invoke_result.ResultCode = "1"
            invoke_result.ResultMessage = "ResourceCode或RestrictCode为空"
            return invoke_result

        storage_config = ""
        file_restrict_model = FileRestrictModel(self.file_context_key)
        file_restrict = file_restrict_model.get_entity("ResourceCode=%s AND RestrictCode=%s", params=[resource_code, restrict_code])
        if not file_restrict:
            invoke_result.ResultCode = "NoExistFileRestrict"
            invoke_result.ResultMessage = "文件配置不存在"
            return invoke_result

        if not dict_file:
            invoke_result.ResultCode = "NoExistFile"
            invoke_result.ResultMessage = "文件不存在"
            return invoke_result

        list_file = dict_file["file"]
        for info in list_file:
            file_name = info["filename"]
            file_body = info["body"]

            invoke_result = self.upload_file(file_body, file_name, file_restrict)
            if invoke_result.ResultCode == "0" and invoke_result.Data:
                invoke_result.Data = invoke_result.Data.ResourcePath

        return invoke_result

    def upload_file(self, stream, file_name, file_restrict, image_width=0, image_height=0, quality=0, is_format_jpeg=0, is_water_mark=0, horizontal_align=0, vertical_align=0):
        """
        :description: 文件上传
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        invoke_result = InvokeResult()
        file_upload_info = FileUploadInfo()
        file_extension = os.path.splitext(file_name)[1]
        if file_restrict.FileExtension != "":
            file_find = file_restrict.FileExtension.find(file_extension.lower().strip("."))
            if file_find == -1:
                invoke_result.ResultCode = "1"
                invoke_result.ResultMessage = f"上传的文件扩展名必须是{file_restrict.FileExtension}，当前文件是:{file_extension}"
                return invoke_result
        file_size = len(stream)
        if file_restrict.FileMaxSize > 0 and file_size / 1024 > file_restrict.FileMaxSize:
            invoke_result.ResultCode = "1"
            invoke_result.ResultMessage = f"对不起支持上传的文件大小为{self.__to_file_size(file_restrict.FileMaxSize * 1024)}，当前的文件大小为{self.__to_file_size(file_size)}，已超出"
            return invoke_result

        if file_extension.__contains__(".gif"):
            return self.switch_upload(stream, file_name, file_restrict)

        if image_width > 0 or image_height > 0 or (file_extension.__contains__(".bmp") or file_extension.__contains__(".png")) and is_format_jpeg or is_water_mark or (quality > 0 and quality < 100):
            # 其他图片格式转jpg
            # im = Image.open(BytesIO(stream))
            # im = im.convert("RGB")
            # im.save("G:\\Temp\\test.jpg")
            return self.switch_upload(stream, file_name, file_restrict)
        else:
            return self.switch_upload(stream, file_name, file_restrict)

    def __to_file_size(self, size):
        """
        :description: 文件大小格式化
        :param size：文件大小
        :return: 
        :last_editors: HuangJingCan
        """
        if size < 1000:
            return '%i' % size + 'size'
        elif 1024 <= size < 1048576:
            return '%.2f' % float(size / 1024) + 'KB'
        elif 1048576 <= size < 1073741824:
            return '%.2f' % float(size / 1048576) + 'MB'
        elif 1073741824 <= size < 1000000000000:
            return '%.2f' % float(size / 1073741824) + 'GB'
        elif 1000000000000 <= size:
            return '%.2f' % float(size / 1000000000000) + 'TB'

    def switch_upload(self, stream, file_name, file_restrict):
        """
        :description: 文件上传
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        invoke_result = InvokeResult()
        file_upload_info = FileUploadInfo()
        file_extension = os.path.splitext(file_name)[1].lower()
        query_size = ""
        image_width = 0
        image_height = 0
        # 返回图片尺寸
        if file_restrict.IsReturnSize == 1:
            im = Image.open(BytesIO(stream))
            if im:
                image_width = im.width
                image_height = im.height
                query_size = f"?w={image_width}&h={image_height}"

        file_storage_path_model = FileStoragePathModel(self.file_context_key)
        file_storage_path = file_storage_path_model.get_entity_by_id(file_restrict.FileStoragePathID)
        if file_storage_path.StorageTypeID == 1:
            # 本地文件
            resource_code = file_restrict.ResourceCode
            create_date_time = TimeHelper.get_now_datetime()
            resource_ver_id = UUIDHelper.get_uuid()

            resource_uuid_file_name = resource_ver_id + file_extension
            virtual_name = RandomUtil.get_random_switch_string(file_storage_path.VirtualName)
            path_format_value = self.get_resource_path_format_value(create_date_time, resource_ver_id, file_restrict.PathFormatCodeType)
            resource_url = self.get_resource_url(virtual_name, file_restrict.AccessModeCodeType, resource_code, path_format_value, resource_uuid_file_name, file_name)
            full_file_name = self.get_resource_full_file_name_path(file_storage_path.StoragePath, file_restrict.AccessModeCodeType, resource_code, path_format_value, resource_uuid_file_name, file_name)

            if file_restrict.IsMd5 == 1:
                file_upload_info.Md5Value = CryptoHelper.md5_encrypt_bytes(stream).upper()

            im = Image.open(BytesIO(stream))
            im.save(full_file_name)

            file_upload_info.FilePath = full_file_name
            file_upload_info.OriginalName = file_name
            file_upload_info.ResourcePath = resource_url

            # return file_upload_info
        elif file_storage_path.StorageTypeID == 2:
            # FTP服务器
            pass
        elif file_storage_path.StorageTypeID == 3:
            # FastDFS文件服务器
            pass
        elif file_storage_path.StorageTypeID in (4, 5, 6, 7, 8):
            if file_storage_path.StorageTypeID == 4:
                # 金山云
                invoke_result = KS3.upload(file_storage_path.StorageConfig, file_name, stream)
            elif file_storage_path.StorageTypeID == 5:
                # 阿里云
                invoke_result = OSS2.upload(file_storage_path.StorageConfig, file_name, stream)
            elif file_storage_path.StorageTypeID == 6:
                # 腾讯云
                invoke_result = COS.upload(file_storage_path.StorageConfig, file_name, stream)
            elif file_storage_path.StorageTypeID == 7:
                # 百度云
                invoke_result = BOS.upload(file_storage_path.StorageConfig, file_name, stream)
            elif file_storage_path.StorageTypeID == 8:
                # AWS
                invoke_result = S3.upload(file_storage_path.StorageConfig, file_name, stream)

            if invoke_result.ResultCode != "0":
                return invoke_result

            if invoke_result.Data:
                file_upload_info.Md5Value = invoke_result.Data["Md5Value"]
                file_upload_info.ResourcePath = invoke_result.Data["ResourcePath"]
                file_upload_info.OriginalName = invoke_result.Data["OriginalName"]
                file_upload_info.FilePath = invoke_result.Data["FilePath"]
                file_upload_info.ImageWidth = invoke_result.Data["ImageWidth"]
                file_upload_info.ImageHeight = invoke_result.Data["ImageHeight"]

        if file_restrict.IsHistory == 1:
            file_history = FileHistory()
            file_history.FileResourceID = file_restrict.FileResourceID
            file_history.FileRestrictID = file_restrict.FileRestrictID
            file_history.FileStoragePathID = file_restrict.FileStoragePathID
            file_history.FileType = file_restrict.FileType
            file_history.FileStatus = 1
            file_history.FileTitle = file_name
            file_history.FileUrl = file_upload_info.ResourcePath
            file_history.CreateDate = TimeHelper.get_now_format_time()
            file_history.CreateUserID = 0

            file_history_model = FileHistoryModel(self.file_context_key)
            file_history_model.add_entity(file_history)

        file_upload_info.ResourcePath = file_upload_info.ResourcePath + query_size
        file_upload_info.ImageWidth = image_width
        file_upload_info.ImageHeight = image_height

        invoke_result.Data = file_upload_info

        return invoke_result

    def get_resource_path_format_value(self, create_date_time, resource_ver_id, path_format_code_id):
        """
        :description: 获取附件路径格式值规则
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        result = ""
        if path_format_code_id == 0:
            result = TimeHelper.datetime_to_format_time(create_date_time, "%Y-%m-%d")
        elif path_format_code_id == 1:
            result = TimeHelper.datetime_to_format_time(create_date_time, "%Y-%m-%d-%H")
        elif path_format_code_id == 2:
            result = str(resource_ver_id)
        return result

    def get_resource_url(self, virtual_name, access_mode_code_value, resource_code, path_format_value, resource_uuid_file_name, resource_file_name):
        """
        :description: 获取资源网址规则 [组合附件网址]
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        resource_url = ""
        uuid_file_name = os.path.splitext(resource_uuid_file_name)[0]
        virtual_name = virtual_name.rstrip("/")
        if path_format_value != "":
            if access_mode_code_value == AccessModeCodeType.VirtualAccess.value:
                resource_url = f"{virtual_name}/{resource_code}/{path_format_value}/{resource_uuid_file_name}"
                return resource_url
            resource_url = f"{virtual_name}/{resource_code}/{path_format_value}/{uuid_file_name}/{resource_file_name}"
            return resource_url
        if access_mode_code_value == AccessModeCodeType.VirtualAccess.value:
            resource_url = f"{virtual_name}/{resource_code}/{resource_uuid_file_name}"
            return resource_url
        resource_url = f"{virtual_name}/{resource_code}/{uuid_file_name}/{resource_file_name}"
        return resource_url

    def get_resource_full_file_name_path(self, storage_path, access_mode_code_value, resource_code, path_format_value, resource_uuid_file_name, resource_file_name, is_create_directory=True):
        """
        :description: 获取附件完整文件名规则 [组合完整文件名]
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        resource_directory = ""
        if storage_path == "":
            resource_directory = self.get_resource_directory_path(access_mode_code_value, resource_code, path_format_value, resource_uuid_file_name)
        else:
            dir_path = self.get_resource_directory_path(access_mode_code_value, resource_code, path_format_value, resource_uuid_file_name)
            resource_directory = os.path.join(storage_path, dir_path)
        if is_create_directory:
            if not os.path.exists(resource_directory):
                os.makedirs(resource_directory)
        if access_mode_code_value == AccessModeCodeType.VirtualOriginalAccess.value:
            return resource_directory + "\\" + resource_file_name
        return resource_directory + "\\" + resource_uuid_file_name

    def get_resource_directory_path(self, access_mode_code_value, resource_code, path_format_value, resource_uuid_file_name):
        """
        :description: 获取资源目录规则
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        resource_directory = ""
        if path_format_value != "":
            resource_directory = os.path.join(resource_code, path_format_value)
        else:
            resource_directory = resource_code
        if access_mode_code_value == AccessModeCodeType.VirtualOriginalAccess.value:
            resource_directory = os.path.join(resource_directory, os.path.splitext(resource_uuid_file_name)[0])

        return resource_directory



# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-04-22 14:32:40
:LastEditTime: 2025-08-26 14:58:25
:LastEditors: ChenXiaolei
:Description: 用户信息扩展类
"""

from seven_studio.models.db_models.user.user_info_model import *
from seven_framework.crypto import *


class UserInfoModelEx(UserInfoModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super().__init__(db_connect_key=db_connect_key, sub_table=sub_table)

    def sign_password(self, login_password="", userid=""):
        if login_password.strip() == '':
            return CryptoHelper.md5_encrypt(config.get_value("default_password", "123654@tz"), userid)
        
        return CryptoHelper.md5_encrypt(login_password, userid).upper()

    def verify_password(self, login_password="", password="", userid=""):
        plaintext_password = self.__decrypt_password(login_password,userid)
        if not plaintext_password:
            return False
        return password.upper() == CryptoHelper.md5_encrypt(plaintext_password, userid).upper()

    def is_force_password(self, user_info):
        if user_info:
            return self.verify_password(config.get_value("default_password", "123654@tz"), user_info.Password, user_info.UserID)
        return False

    def is_exist_phone(self,phone,self_user_id=None):
        if phone.strip() == '':
            return False
        condition = "Phone=%s"
        params = [phone]
        if self_user_id:
            condition += " AND UserID!=%s"
            params.append(self_user_id)
        return self.get_total(condition,params=params)>0
    
    def __decrypt_password(self, password,user_id):
        """
        :description: 解密密码
        :return 明文密码
        :last_editors: ChenXiaolei
        """        
        try:
            plaintext_password = CryptoHelper.aes_decrypt(password,user_id.replace("-",""))
        except Exception as e:
            plaintext_password = ""
            
        return plaintext_password


"""
:Author: HuangJingCan
:Date: 2020-04-15 09:56:24
:LastEditTime: 2024-09-18 09:56:18
:LastEditors: ChenXiaolei
:Description: 权限角色栏目相关
"""
from asq.initiators import query
from seven_studio.utils.dict import *
from seven_framework.time import *

from seven_studio.models.db_models.role.role_power_model_ex import *
from seven_studio.models.db_models.role.role_user_model import *
from seven_studio.models.db_models.role.role_info_model import *
from seven_studio.models.db_models.menu.menu_info_model_ex import *
from seven_studio.models.db_models.menu.menu_cote_model import *
from seven_studio.models.db_models.user.user_info_model_ex import *
from seven_studio.models.db_models.product.product_user_model import *
from seven_studio.models.enum import ButtonPlace
from seven_studio.models.dto_model import *


class PowerModel():
    """
    :description: 权限相关操作类
    """
    def __init__(self, db_connect_key='db_sevenstudio', is_super=False, user_id="", product_id=0):
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.is_super = is_super
        self.user_id = user_id
        self.product_id = product_id

    ROLE_POWERS = []

    def get_power_menu_list(self):
        """
        :description: 获取栏目列表
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        manage_context_key = self.db_connect_key
        menu_info_list = []
        if self.is_super:
            menu_info_list = MenuInfoModel(manage_context_key).get_list(order_by="SortIndex ASC")
        else:
            role_user_list = RoleUserModel(manage_context_key).get_list("UserID=%s", params=self.user_id)
            if len(role_user_list) == 0:
                return menu_info_list
            # self.ROLE_POWERS = RolePowerModelEx(manage_context_key).get_role_power_list([i.RoleID for i in role_user_list])
            role_power_list = RolePowerModelEx(manage_context_key).get_role_power_list([i.RoleID for i in role_user_list])
            self.ROLE_POWERS = RolePowerEx().get_list_by_role_power_list(role_power_list)
            condition = "IsPower=0"
            if len(self.ROLE_POWERS) > 0:
                condition += " OR "
                condition += f"MenuID IN ({str([i.MenuID for i in self.ROLE_POWERS]).strip('[').strip(']')})"
            menu_info_list = MenuInfoModel(manage_context_key).get_list(condition, order_by="SortIndex ASC")

        return MenuInfoEx().get_list_by_menu_list(menu_info_list)

    def get_platform_power_menu_list(self):
        """
        :description: 获取权限菜单
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        menu_info_list = self.get_power_menu_list()
        menu_item_list = []

        # 平台管理权限
        # menu_info_list_plat = [i for i in menu_info_list if i.MenuType == 1 and i.MenuID == config.get_value("menu_id_platform", "03E5D2A0-DB59-47F6-8F10-1ACDEFE9BDDD")]
        menu_info_list_plat = [i for i in menu_info_list if i.MenuType == 1]
        for menu_info in menu_info_list_plat:
            curr_menu_item_dto = PowerMenuInfoDto()
            curr_menu_item_dto.MenuID = menu_info.MenuID
            curr_menu_item_dto.MenuName = menu_info.MenuName
            curr_menu_item_dto.MenuIcon = menu_info.MenuIcon
            curr_menu_item_dto.ApiPath = menu_info.ApiPathValue
            curr_menu_item_dto.ViewPath = menu_info.ViewPathValue
            hidden_power_menu_list = []
            self.__get_menu_item_dto_list(curr_menu_item_dto, menu_info_list, hidden_power_menu_list)
            if menu_info.MenuCoteID > 0:
                menu_list = self.__get_power_cote_menu_item(menu_info.MenuCoteID, curr_menu_item_dto, (self.is_super or menu_info.IsPower == 0))
                # if len(menu_list) > 0:
                if menu_list:
                    curr_menu_item_dto.MenuItemDtoList = menu_list
            menu_item_list.append(curr_menu_item_dto.__dict__)
        return menu_item_list

    def __get_menu_item_dto_list(self, menu_item, child_menu_infos, hidden_power_menu_list, depth=0):
        """
        :description: 获取菜单数据
        :param menu_item: 当前菜单信息
        :param child_menu_infos: 子菜单列表
        :param hidden_power_menu_list: 隐藏权限菜单列表
        :param depth: 深度
        :return: 
        :last_editors: HuangJingCan
        """
        menu_info_list = [i for i in child_menu_infos if i.ParentID == menu_item.MenuID]
        for menu_info in menu_info_list:
            if menu_info.MenuType == 3 and menu_info.IsShow == 1:
                curr_menu_button_dto = PowerButtonDto()
                curr_menu_button_dto.ID = menu_info.MenuID
                curr_menu_button_dto.Title = menu_info.MenuName
                curr_menu_button_dto.Icon = menu_info.MenuIcon
                curr_menu_button_dto.ApiPath = menu_info.ApiPathValue
                curr_menu_button_dto.ViewPath = menu_info.ViewPathValue
                curr_menu_button_dto.Path = "" if menu_info.ViewPath.strip() == "" else menu_info.RedirctPathValue
                curr_menu_button_dto.CommandName = menu_info.CommandName
                curr_menu_button_dto.CommandParms = menu_info.CommandParms
                curr_menu_button_dto.IsHidden = menu_info.IsShow == 0
                curr_menu_button_dto.ButtonPlace = menu_info.ButtonPlace
                curr_menu_button_dto.ButtonColor = menu_info.ButtonColor
                curr_menu_button_dto.ShowCondition = menu_info.ShowCondition
                menu_item.MenuButtonDtoList.append(curr_menu_button_dto.__dict__)

            child_menu_info_list = [i for i in child_menu_infos if menu_info.MenuID in i.IDPath]
            if menu_info.ViewPath.strip() != "" or len([i for i in child_menu_info_list if i.MenuType == 2]) > 0:
                curr_menu_item_dto = PowerMenuInfoDto()
                curr_menu_item_dto.MenuID = menu_info.MenuID
                curr_menu_item_dto.MenuName = menu_info.MenuName
                curr_menu_item_dto.MenuIcon = menu_info.MenuIcon
                curr_menu_item_dto.ApiPath = menu_info.ApiPathValue
                curr_menu_item_dto.ViewPath = menu_info.ViewPathValue
                curr_menu_item_dto.Path = menu_info.RoutePathValue
                curr_menu_item_dto.IsHidden = True if menu_info.MenuType == 3 else menu_info.IsShow == 0

                self.__get_menu_item_dto_list(curr_menu_item_dto, child_menu_info_list, hidden_power_menu_list, depth + 1)

                list_count = len([i for i in child_menu_info_list if i.MenuType == 3 and i.ViewPath.strip() != ""])
                if (curr_menu_item_dto.ViewPath.strip() != "" and depth == 0) or (menu_info.MenuType != 3 and list_count > 0):
                    power_menu_info_dto_curr = PowerMenuInfoDto()
                    power_menu_info_dto_curr.MenuID = menu_info.MenuChildID
                    power_menu_info_dto_curr.MenuIcon = menu_info.MenuIcon
                    power_menu_info_dto_curr.MenuName = menu_info.MenuName
                    power_menu_info_dto_curr.ApiPath = menu_info.ApiPathValue
                    power_menu_info_dto_curr.ViewPath = menu_info.ViewPathValue
                    power_menu_info_dto_curr.Path = menu_info.RoutePathValue
                    power_menu_info_dto_curr.IsHidden = True
                    curr_menu_item_dto.MenuItemDtoList.insert(0, power_menu_info_dto_curr.__dict__)

                if (menu_info.MenuCoteID > 0):
                    is_power = self.is_super or menu_info.IsPower == 0
                    self.__get_power_cote_menu_item(menu_info.MenuCoteID, curr_menu_item_dto, is_power)

                menu_item.MenuItemDtoList.append(curr_menu_item_dto.__dict__)

    def __get_power_cote_menu_item(self, coteID, curr_menu_info, is_power):
        """
        :description: 获取栏目菜单数据
        :param coteID: 栏目菜单码
        :param curr_menu_info: 当前栏目信息
        :param is_power: 是否超管
        :return: 
        :last_editors: HuangJingCan
        """
        menu_item_list = curr_menu_info.MenuItemDtoList
        curr_menu_info.MenuItemDtoList = []
        if coteID > 0:
            menu_cote = MenuCoteModel(self.db_connect_key).get_entity_by_id(coteID)
            if not menu_cote:
                return []
            menu_cote_list = self.__get_cote_menu_data(menu_cote)
            menu_cote_id = curr_menu_info.MenuID + "$"

            cote_menu_info_list = []
            for menu_cote_item in menu_cote_list:
                if not self.__check_menu_power(is_power, curr_menu_info.MenuID, menu_cote_item[menu_cote.IDName]):
                    continue
                cote_menu_info = MenuInfo()
                cote_menu_info.MenuID = menu_cote_id + str(menu_cote_item[menu_cote.IDName])
                cote_menu_info.MenuName = menu_cote_item[menu_cote.Name]
                cote_menu_info.ParentID = menu_cote_id + str(menu_cote_item[menu_cote.ParentIDName]) if menu_cote.ParentIDName.strip() != "" else menu_cote_id + menu_cote.RootIDValue
                cote_menu_info.IDPath = menu_cote_item[menu_cote.IDPathName] if menu_cote.IDPathName.strip() != "" else ""
                cote_menu_info.TargetUrl = str(menu_cote_item[menu_cote.IDName])
                cote_menu_info.ViewPath = curr_menu_info.ViewPath
                cote_menu_info = MenuInfoEx().get_entity_by_menu_info(cote_menu_info)
                cote_menu_info_list.append(cote_menu_info.__dict__)

            if len(cote_menu_info_list) == 1:
                curr_menu_info.MenuItemDtoList = []

            for menu_info in [i for i in cote_menu_info_list if i["ParentID"] == menu_cote_id + menu_cote.RootIDValue]:
                curr_menu_item_dto = PowerMenuInfoDto()
                curr_menu_item_dto.MenuID = menu_info["MenuID"]
                curr_menu_item_dto.MenuName = menu_info["MenuName"]
                curr_menu_item_dto.ViewPath = curr_menu_info.ViewPath
                curr_menu_item_dto.Path = menu_info["RoutePathValue"]
                curr_menu_item_dto.IsHidden = len(cote_menu_info_list) == 1

                if len(cote_menu_info_list) == 1:
                    childInfo = PowerMenuInfoDto()
                    childInfo.MenuID = str(curr_menu_item_dto.MenuID) + ":child"
                    childInfo.MenuName = menu_info["MenuName"]
                    childInfo.ViewPath = curr_menu_info.ViewPath
                    childInfo.Path = menu_info["RoutePathValue"]
                    childInfo.IsHidden = True
                    curr_menu_item_dto.MenuItemDtoList.append(childInfo.__dict__)
                else:
                    curr_menu_info.Path = curr_menu_item_dto.Path

                if [i for i in cote_menu_info_list if i["ParentID"] == menu_info["MenuID"]]:
                    self.__get_child_cote_menu_list(menu_item_list, curr_menu_info.MenuButtonDtoList, curr_menu_item_dto, cote_menu_info_list, is_power)
                else:
                    curr_menu_item_dto.MenuButtonDtoList.extend(curr_menu_info.MenuButtonDtoList)
                    if len(menu_item_list) > 1:
                        curr_menu_item_dto.MenuItemDtoList.extend(self.__to_cote_menu_list(menu_item_list, menu_info["TargetUrl"], is_power))

                curr_menu_info.MenuItemDtoList.append(curr_menu_item_dto.__dict__)

    def __get_cote_menu_data(self, menu_cote):
        """
        :description: 获取栏目菜单数据
        :param menu_cote: 栏目菜单码
        :return: 
        :last_editors: HuangJingCan
        """
        field_parms = f"{menu_cote.IDName},{menu_cote.Name}"
        if menu_cote.ParentIDName.strip() != "":
            field_parms += f",{menu_cote.ParentIDName}"
        if menu_cote.IDPathName.strip() != "":
            field_parms += f",{menu_cote.IDPathName}"

        condition = ""
        if menu_cote.Condtion.strip() == "":
            condition = f" ORDER BY {menu_cote.SortExpression}"
        else:
            condition = f"{menu_cote.Condtion} ORDER BY {menu_cote.SortExpression}"

        sql = f"SELECT {field_parms} FROM {menu_cote.CoteTableName}{condition}"
        return MySQLHelper(config.get_value(menu_cote.ConnectionStringName)).fetch_all_rows(sql)

    def __check_menu_power(self, is_power, menu_id, cote_id):
        """
        :description: 菜单权限判断
        :param is_power: 是否超管
        :param menu_id: 菜单id
        :param cote_id: 栏目id
        :return: 
        :last_editors: HuangJingCan
        """
        is_contains = [i for i in self.ROLE_POWERS if f"{i.MenuID}${i.CoteID}".lower() == f"{menu_id}${cote_id}".lower()]
        return bool(is_power != 0 or is_contains)

    def __get_child_cote_menu_list(self, root_power_menu_list, button_menu_dto_list, menu_item, menu_info_list, is_super):
        """
        :description: 获取栏目菜单列表
        :param root_power_menu_list: 根目录菜单列表
        :param button_menu_dto_list: 按钮菜单列表
        :param menu_item: 当前菜单
        :param menu_info_list: 菜单信息列表
        :param is_super: 是否超管
        :return: 
        :last_editors: HuangJingCan
        """
        for curr_menu_info in [i for i in menu_info_list if i["ParentID"] == menu_item.MenuID]:
            curr_menu_item_dto = PowerMenuInfoDto()
            curr_menu_item_dto.MenuID = curr_menu_info["MenuID"]
            curr_menu_item_dto.MenuName = curr_menu_info["MenuName"]
            curr_menu_item_dto.ViewPath = curr_menu_info["ViewPathValue"]
            curr_menu_item_dto.Path = curr_menu_info["RoutePathValue"]

            if [i for i in menu_info_list if i["ParentID"] == curr_menu_info["MenuID"]]:
                self.__get_child_cote_menu_list(root_power_menu_list, button_menu_dto_list, curr_menu_item_dto, menu_info_list, is_super)
            else:
                for curr_power_button_dto in button_menu_dto_list:
                    if is_super or [i for i in self.ROLE_POWERS if i.MenuCoteID in (curr_power_button_dto['ID'] + "$" + curr_menu_info["TargetUrl"])]:
                        curr_menu_item_dto.MenuButtonDtoList.append(curr_power_button_dto)
                curr_menu_item_dto.MenuItemDtoList.extend(self.__to_cote_menu_list(root_power_menu_list, curr_menu_info["TargetUrl"], is_super))
                menu_item.MenuItemDtoList.extend(self.__to_cote_menu_list(root_power_menu_list, curr_menu_info["TargetUrl"], is_super, True))

            menu_item.MenuItemDtoList.append(curr_menu_item_dto.__dict__)
            if len(menu_item.MenuItemDtoList) == 1:
                childInfo = PowerMenuInfoDto()
                childInfo.MenuID = curr_menu_item_dto.MenuID + ":child"
                childInfo.MenuName = curr_menu_info["MenuName"]
                childInfo.ViewPath = curr_menu_info["ViewPathValue"]
                childInfo.Path = curr_menu_info["RoutePathValue"]
                childInfo.IsHidden = True
                curr_menu_item_dto.MenuItemDtoList.append(childInfo.__dict__)

    def __to_cote_menu_list(self, menu_info_list, menu_cote_key, is_super, is_hidden=False):
        """
        :description: 获取栏目菜单
        :param menu_info_list: 当前菜单信息
        :param menu_cote_key: 跳转地址
        :param is_super: 是否超管
        :param is_hidden: 是否隐藏
        :return: 
        :last_editors: HuangJingCan
        """
        menu_item_list = menu_info_list if is_super else query(menu_info_list).where(lambda x: query(self.ROLE_POWERS).select(lambda y: y["MenuCoteID"]).contains(str(x["MenuID"]) + "$" + menu_cote_key)).to_list()
        for curr_power_menu_info_dto in menu_item_list:
            curr_power_menu_info_dto['MenuID'] = curr_power_menu_info_dto['MenuID'] + "$" + menu_cote_key
            curr_power_menu_info_dto['Path'] = "/" + curr_power_menu_info_dto['MenuID'] + curr_power_menu_info_dto['ViewPath']

            if is_hidden:
                curr_power_menu_info_dto['MenuID'] = curr_power_menu_info_dto['ViewPath'] + "hidden"

            c_menu_list = curr_power_menu_info_dto['MenuButtonDtoList']
            curr_power_menu_info_dto['MenuButtonDtoList'] = c_menu_list if is_super else query(c_menu_list).where(lambda x: query(self.ROLE_POWERS).select(lambda y: y["MenuCoteID"]).contains(str(x["ID"]) + "$" + menu_cote_key)).to_list()

            curr_power_menu_info_dto['IsHidden'] = True if curr_power_menu_info_dto['IsHidden'] else is_hidden

            if len(curr_power_menu_info_dto['MenuItemDtoList']) == 1:
                curr_power_menu_info_dto['MenuItemDtoList'][0]['MenuID'] = curr_power_menu_info_dto['MenuID'] + ":Child"
                curr_power_menu_info_dto['MenuItemDtoList'][0]['Path'] = curr_power_menu_info_dto['Path']
            elif len(curr_power_menu_info_dto['MenuItemDtoList']) > 1:
                curr_power_menu_info_dto['MenuItemDtoList'] = self.__to_cote_menu_list(curr_power_menu_info_dto['MenuItemDtoList'], menu_cote_key, is_super, is_hidden)

        return menu_item_list

    def get_menu_item_tree(self, is_load_cote_menu=True):
        """
        :description: 获取栏目树
        :param is_load_cote_menu: 是否加载栏目菜单
        :return: 
        :last_editors: HuangJingCan
        """
        menu_info_list = self.get_power_menu_list()
        menu_item_list = []
        for menu_info in [i for i in menu_info_list if i.MenuType == 1 and i.ParentID == ""]:
            curr_menu_dto = DictUtil.auto_mapper(MenuInfoDto(), menu_info.__dict__)
            self.__get_child_menu_item_list(curr_menu_dto, menu_info_list, is_load_cote_menu)
            if is_load_cote_menu and menu_info.MenuCoteID > 0:
                curr_menu_dto.ChildList = self.__get_cote_menu_item(menu_info, curr_menu_dto.ChildList)
            menu_item_list.append(curr_menu_dto.__dict__)
        return menu_item_list

    def __get_child_menu_item_list(self, menu_item, menu_infos, is_load_cote_menu):
        """
        :description: 获取子菜单
        :param menu_item: 当前菜单信息
        :param menu_infos: 子菜单列表
        :param is_load_cote_menu: 是否加载栏目菜单
        :return: 
        :last_editors: HuangJingCan
        """
        menu_item_list = []
        for curr_menu_info in [i for i in menu_infos if i.ParentID == menu_item.MenuID]:
            curr_menu_dto = DictUtil.auto_mapper(MenuInfoDto(), curr_menu_info.__dict__)
            id_path_list = [i for i in menu_infos if curr_menu_info.MenuID in i.IDPath]
            self.__get_child_menu_item_list(curr_menu_dto, id_path_list, is_load_cote_menu)
            if is_load_cote_menu and curr_menu_info.MenuCoteID > 0:
                curr_menu_dto.ChildList = self.__get_cote_menu_item(curr_menu_info, curr_menu_dto.ChildList)
            if curr_menu_dto.MenuCoteKey != "":
                curr_menu_dto.MenuID = curr_menu_dto.MenuID + "$" + curr_menu_dto.MenuCoteKey
            menu_item.ChildList.append(curr_menu_dto.__dict__)
            menu_item_list.append(menu_item)

        return menu_item_list

    def __get_cote_menu_item(self, curr_menu_info, child_menu_info_list):
        """
        :description: 获取栏目菜单
        :param curr_menu_info: 当前菜单信息
        :param child_menu_info_list: 子菜单列表
        :return: 
        :last_editors: HuangJingCan
        """
        menu_item_list = []
        cote_menu_info_list = []
        if curr_menu_info.MenuCoteID > 0:
            menu_cote = MenuCoteModel(self.db_connect_key).get_entity_by_id(curr_menu_info.MenuCoteID)
            if not menu_cote:
                return menu_item_list

            field = f"{menu_cote.IDName},{menu_cote.Name}{(',' + menu_cote.ParentIDName if menu_cote.ParentIDName!='' else '')}{(',' + menu_cote.IDPathName if menu_cote.IDPathName!='' else '')}"
            condition = f"{(' WHERE ' + menu_cote.Condtion if menu_cote.Condtion!='' else '')}{(' ORDER BY ' + menu_cote.SortExpression if menu_cote.SortExpression!='' else '')}"
            sql = f"SELECT {field} FROM {menu_cote.CoteTableName}{condition}"
            menu_cote_table = MySQLHelper(config.get_value(menu_cote.ConnectionStringName)).fetch_all_rows(sql)

            cote_id = curr_menu_info.MenuID + "$"
            for dr in menu_cote_table:
                if not self.__check_menu_power(self.is_super, curr_menu_info.MenuID, dr[menu_cote.IDName]):
                    continue
                cote_menu_info = MenuInfo()
                cote_menu_info.MenuID = cote_id + str(dr[menu_cote.IDName])
                cote_menu_info.MenuName = dr[menu_cote.Name]
                cote_menu_info.ParentID = cote_id + str(dr[menu_cote.ParentIDName]) if menu_cote.ParentIDName != "" else cote_id + menu_cote.RootIDValue
                cote_menu_info.IDPath = dr[menu_cote.IDPathName] if menu_cote.IDPathName != "" else ""
                cote_menu_info.TargetUrl = dr[menu_cote.IDName]
                cote_menu_info_list.append(cote_menu_info.__dict__)

            for menu_info in [i for i in cote_menu_info_list if i["ParentID"] == cote_id + menu_cote.RootIDValue]:
                curr_menu_dto = DictUtil.auto_mapper(MenuInfoDto(), menu_info)
                if len([i for i in cote_menu_info_list if i["ParentID"] == curr_menu_dto.MenuID]) > 0:
                    self.__get_child_cote_menu_item_list(curr_menu_dto, cote_menu_info_list, child_menu_info_list)
                else:
                    curr_child_menu_info = []
                    for c_menu_info_dto in child_menu_info_list:
                        new_c_menu_info_dto = MenuInfoDto()
                        new_c_menu_info_dto.MenuID = c_menu_info_dto['MenuID'] + "$" + str(menu_info['TargetUrl'])
                        new_c_menu_info_dto.MenuName = c_menu_info_dto['MenuName']
                        new_c_menu_info_dto.MenuIcon = c_menu_info_dto['MenuIcon']
                        new_c_menu_info_dto.ParentID = c_menu_info_dto['MenuID']
                        new_c_menu_info_dto.IDPath = c_menu_info_dto['IDPath']
                        new_c_menu_info_dto.ChildList = c_menu_info_dto['ChildList']
                        for info in new_c_menu_info_dto.ChildList:
                            info['MenuID'] = info['MenuID'] + "$" + curr_menu_info.TargetUrl
                            info['ParentID'] = str(info['ParentID']) + "$" + str(menu_info['TargetUrl'])
                            self.__revise_child_cote_menu_list(info, menu_info['TargetUrl'])

                        curr_child_menu_info.append(new_c_menu_info_dto.__dict__)

                    curr_menu_dto.ChildList.extend(curr_child_menu_info)

                menu_item_list.append(curr_menu_dto.__dict__)

        return menu_item_list

    def __revise_child_cote_menu_list(self, menu_info_dto, cote_key):
        """
        :description: 更改子菜单中栏目数据的MenuID和ParentID
        :param menu_info_dto: 需要修改的菜单信息
        :param cote_key: cote_key
        :return: 
        :last_editors: HuangJingCan
        """
        if menu_info_dto['ChildList']:
            for info in menu_info_dto['ChildList']:
                info['MenuID'] = str(info['MenuID']) + "$" + str(cote_key)
                info['ParentID'] = str(info['ParentID']) + "$" + str(cote_key)
                self.__revise_child_cote_menu_list(info, cote_key)

    def __get_child_cote_menu_item_list(self, menu_item, menu_infos, child_menu_info_list):
        """
        :description: 获取子菜单中栏目数据
        :param menu_item: 当前菜单信息
        :param menu_infos: 子菜单信息
        :param child_menu_info_list: 子菜单列表
        :return: 
        :last_editors: HuangJingCan
        """
        menu_item_list = []
        for curr_menu_info in [i for i in menu_infos if i['ParentID'] == menu_item.MenuID]:
            curr_menu_dto = DictUtil.auto_mapper(MenuInfoDto(), curr_menu_info)
            child_menu_list = [i for i in menu_infos if i['ParentID'] == curr_menu_info['MenuID']]
            if not child_menu_list:
                curr_child_menu_info = []
                for c_menu_info_dto in child_menu_info_list:
                    new_c_menu_info_dto = MenuInfoDto()
                    new_c_menu_info_dto.MenuID = str(c_menu_info_dto['MenuID']) + "$" + str(curr_menu_info['TargetUrl'])
                    new_c_menu_info_dto.MenuIcon = c_menu_info_dto['MenuIcon']
                    new_c_menu_info_dto.MenuName = c_menu_info_dto['MenuName']
                    new_c_menu_info_dto.ParentID = str(curr_menu_info['MenuID']) + "$" + str(curr_menu_info['TargetUrl'])
                    new_c_menu_info_dto.IDPath = c_menu_info_dto['IDPath']
                    new_c_menu_info_dto.ChildList = c_menu_info_dto['ChildList']
                    for info in c_menu_info_dto['ChildList']:
                        info['MenuID'] = str(info['MenuID']) + "$" + str(curr_menu_info['TargetUrl'])

                    curr_child_menu_info.append(new_c_menu_info_dto.__dict__)

                curr_menu_dto.ChildList.extend(curr_child_menu_info)
            else:
                self.__get_child_cote_menu_item_list(curr_menu_dto, child_menu_list, child_menu_info_list)

            menu_item.ChildList.append(curr_menu_dto.__dict__)
            menu_item_list.append(menu_item.__dict__)

        return menu_item_list

    def get_power_menu_role_list(self, menu_id):
        """
        :description: 根据菜单id获取角色和用户
        :param menu_id：菜单id
        :return: 
        :last_editors: HuangJingCan
        """
        menu_role_list = []
        rowle_power_list = RolePowerModelEx(self.db_connect_key).get_list("MenuID=%s", params=menu_id)
        if rowle_power_list:
            role_info_list = RoleInfoModel(self.db_connect_key).get_list("RoleID IN ("+','.join("'"+str(item.RoleID)+"'" for item in rowle_power_list)+")")
            role_user_list = RoleUserModel(self.db_connect_key).get_list("RoleID IN ("+','.join("'"+str(item.RoleID)+"'" for item in rowle_power_list)+")")
            user_info_list = UserInfoModel(self.db_connect_key).get_list("UserID IN ("+','.join("'"+str(item.UserID)+"'" for item in role_user_list)+")")
            for curr_role_info in role_info_list:
                curr_user_info_list = [i for j in [i.UserID for i in role_user_list if i.RoleID == curr_role_info.RoleID] for i in user_info_list if j in i.UserID]
                info = {
                    "RoleID": curr_role_info.RoleID,
                    "RoleName": curr_role_info.RoleName,
                    "Summary": curr_role_info.Summary,
                }
                curr_user_dict = [user_info.__dict__ for user_info in curr_user_info_list]
                info["UserInfoList"] = curr_user_dict
                menu_role_list.append(info)
        return menu_role_list

    def remove_role_user(self, role_id, user_id):
        """
        :description: 删除用户角色
        :param role_id: 角色id
        :param user_id: 用户id
        :return: 
        :last_editors: HuangJingCan
        """
        role_user_model = RoleUserModel(self.db_connect_key)
        if self.is_super:
            role_user_model.del_entity("RoleID=%s and UserID=%s", [role_id, user_id])
        else:
            user_info = UserInfoModel().get_entity_by_id(user_id)
            if user_info and user_info.ChiefUserID == user_id:
                role_user_model.del_entity("RoleID=%s and UserID=%s", [role_id, user_id])

    def set_role(self, role_info, user_id_list, menu_id_list, is_add=False):
        """
        :description: 设置角色
        :param role_info: 角色信息
        :param user_id_list: 用户id列表
        :param menu_id_list: 菜单id列表
        :param is_add:是否新增
        :return: 
        :last_editors: HuangJingCan
        """
        role_info_model = RoleInfoModel(self.db_connect_key)
        user_id_list = [i for i in user_id_list if i != ""]
        menu_id_list = [i for i in menu_id_list if i != ""]

        if is_add:
            role_info_model.add_entity(role_info)
        else:
            role_info_model.update_entity(role_info)

        if len(user_id_list) > 0:
            self.add_role_user(role_info.RoleID, user_id_list)

        if len(menu_id_list) > 0:
            self.add_role_menu(role_info.RoleID, menu_id_list)

        result = DictUtil.auto_mapper(RoleUserDto(), role_info.__dict__)
        result.RoleUserIds = user_id_list
        result.RoleMenuIds = menu_id_list
        result.IsAdd = is_add
        return result

    def add_role_user(self, role_id, user_id_list):
        """
        :description: 添加角色用户
        :param role_id: 角色id
        :param user_id_list: 用户id列表
        :return: 
        :last_editors: HuangJingCan
        """
        role_user_mode = RoleUserModel(self.db_connect_key)
        role_user_mode.del_entity("RoleID=%s", role_id)
        if len(user_id_list) > 0:
            role_user_list = []
            for user_id in user_id_list:
                role_user = RoleUser()
                role_user.RoleUserID = CryptoHelper.md5_encrypt_int(role_id + user_id)
                role_user.UserID = user_id
                role_user.RoleID = role_id
                role_user.CreateDate = TimeHelper.get_now_format_time()
                role_user_list.append(role_user)
            role_user_mode.add_list(role_user_list, True, True)

    def add_role_menu(self, role_id, menu_id_list):
        """
        :description: 添加角色菜单
        :param role_id: 角色id
        :param menu_id_list: 菜单id列表
        :return: 
        :last_editors: HuangJingCan
        """
        role_power_mode = RolePowerModel(self.db_connect_key)
        role_power_mode.del_entity("RoleID=%s", role_id)
        if len(menu_id_list) > 0:
            role_power_list = []
            for menu_id in menu_id_list:
                role_power = RolePower()
                role_power.RolePowerID = CryptoHelper.md5_encrypt_int(role_id + menu_id)
                cote_menu_array = menu_id.split("$")
                if len(cote_menu_array) > 1:
                    role_power.MenuID = cote_menu_array[0]
                    role_power.CoteID = cote_menu_array[1]
                else:
                    role_power.MenuID = menu_id
                role_power.RoleID = role_id
                role_power_list.append(role_power)

            role_power_mode.add_list(role_power_list, True)

    def set_user(self, user_info, role_id_list, product_id_list, password, change_pw=False, is_add=False):
        """
        :description: 设置用户信息/角色/产品
        :param user_info: 用户信息
        :param role_id_list: 角色id列表
        :param product_id_list: 产品id列表
        :param password: 密码
        :param change_pw: 修改密码
        :param is_add: 是否添加
        :return: 
        :last_editors: HuangJingCan
        """
        user_info_model = UserInfoModel(self.db_connect_key)
        base_user_info_model = UserInfoModel(config.get_value("base_manage_context_key", "db_sevenstudio"))
        role_id_list = [i for i in role_id_list if i != ""]
        product_id_list = [i for i in product_id_list if i != ""]
        update_field = ["IsSuper", "Account", "Email", "LoginIP", "PasswordQuestion", "PasswordAnswer", "IsLock", "FaildLoginCount", "FaildQuestionCount", "UserName", "NickName", "JobNo", "Avatar", "LoginDate", "Phone", "PersonalitySignature", "ChiefUserID"]

        if change_pw:
            update_field.append("Password")
        if is_add:
            base_user_info = base_user_info_model.get_entity("Account=%s", params=user_info.Account)
            if base_user_info:
                user_info.UserID = base_user_info.UserID
            else:
                user_info.UserID = UUIDHelper.get_uuid()
                base_user_info_model.add_entity(user_info)
            user_info_model.add_entity(user_info, True)
            
            if change_pw:
                user_info.Password = UserInfoModelEx().sign_password(password, user_info.UserID)
            else:
                user_info.Password = UserInfoModelEx().sign_password(config.get_value("default_password", "88888888"))
        elif change_pw:
            user_info.Password = UserInfoModelEx().sign_password(password, user_info.UserID)

        user_info_model.update_entity(user_info, field_list=update_field)
        base_user_info_model.update_table("Password=%s", "UserID=%s", params=[user_info.Password, user_info.UserID])

        if role_id_list:
            self.add_user_role(user_info.UserID, role_id_list)

        if product_id_list:
            self.add_product_user(user_info.UserID, product_id_list)

        self.set_base_user(user_info)

        result = DictUtil.auto_mapper(UserRoleDto(), user_info.__dict__)
        result.IsAdd = is_add
        return result

    def add_user_role(self, user_id, role_id_list):
        """
        :description: 添加用户角色
        :param user_id: 用户id
        :param role_id_list: 角色id列表
        :return: 
        :last_editors: HuangJingCan
        """
        role_user_model = RoleUserModel(self.db_connect_key)
        role_user_model.del_entity("UserID=%s", user_id)
        if role_id_list:
            role_user_list = []
            for role_id in role_id_list:
                role_user = RoleUser()
                role_user.RoleUserID = CryptoHelper.md5_encrypt_int(role_id + user_id)
                role_user.UserID = user_id
                role_user.RoleID = role_id
                role_user.CreateDate = TimeHelper.get_now_format_time()
                role_user_list.append(role_user)
            role_user_model.add_list(role_user_list, True, True)

    def add_product_user(self, user_id, product_id_list):
        """
        :description: 添加产品用户
        :param user_id: 用户id
        :param role_id_list: 产品id列表
        :return: 
        :last_editors: HuangJingCan
        """
        product_user_model = ProductUserModel(config.get_value("base_manage_context_key", "db_sevenstudio"))
        product_user_model.del_entity("UserID=%s", user_id)
        if len(product_id_list) > 0:
            product_user_list = []
            for product_id in product_id_list:
                product_user = ProductUser()
                product_user.UserID = user_id
                product_user.ProductID = product_id
                product_user_list.append(product_user)
            product_user_model.add_list(product_user_list, True, True)

    def set_base_user(self, user_info):
        """
        :description: 子产品将用户同步回主库之中
        :param user_info: 用户信息
        :return: 
        :last_editors: HuangJingCan
        """
        if self.product_id > 0:
            base_user_info_model = UserInfoModel(config.get_value("base_manage_context_key"), "db_sevenstudio")
            base_product_user_model = ProductUserModel(config.get_value("base_manage_context_key"), "db_sevenstudio")

            base_product_user = base_product_user_model.get_entity("ProductID=%s and UserID=%s", params=[self.product_id, user_info.UserID])

            if not base_product_user:
                product_user = ProductUser()
                product_user.ProductID = self.product_id
                product_user.UserID = user_info.UserID
                base_product_user_model.add_entity(product_user)
                base_user_info_model.add_entity(user_info, True)
            else:
                base_user_info_model.update_entity(user_info, "Password")

    def export_sql(self, menu_id, mode=3):
        """
        :description: 导出sql语句
        :param menu_id：栏目id
        :param mode：模式类型（1-新增，2-更新，3-同步）
        :return: str
        :last_editors: HuangJingCan
        """
        sql = ""
        menu_info_model = MenuInfoModel(self.db_connect_key)
        menu_info = menu_info_model.get_entity_by_id(menu_id)

        if menu_info:
            model_list = menu_info_model.get_list(f"IDPath like '{menu_info.IDPath}%'")
            if mode == 1:
                sql = menu_info_model.build_add_sql(model_list, True)
            elif mode == 2:
                sql = menu_info_model.build_update_sql(model_list)
            else:
                sql = menu_info_model.build_data_sql(model_list)

        return sql

    def remove_user(self, curr_user_id, user_id):
        """
        :description: 删除用户
        :param curr_user_id: 当前用户id
        :param user_id: 用户id
        :return {*}
        :last_editors: HuangJingCan
        """
        user_info_model = UserInfoModel(self.db_connect_key)

        if self.is_super:
            user_info_model.del_entity("UserID=%s", user_id)
        else:
            user_info = user_info_model.get_entity_by_id(user_id)
            if user_info and user_info.ChiefUserID == curr_user_id:
                user_info_model.del_entity("UserID=%s", user_id)

    def copy_user_role(self, copy_user_id, user_id):
        """
        :description: 复制权限
        :param copy_user_id: 复制用户id
        :param user_id: 用户id
        :return {*}
        :last_editors: HuangJingCan
        """
        role_id_list = RoleUserModel(self.db_connect_key).get_list("UserID=%s", params=copy_user_id)
        role_id_list = [i.RoleID for i in role_id_list if i != ""]
        if role_id_list:
            self.add_user_role(user_id, role_id_list)


# -*- coding: utf-8 -*-
"""
:Author: ChenXiaolei
:Date: 2021-01-06 18:36:26
:LastEditTime: 2021-01-08 11:33:37
:LastEditors: ChenXiaolei
:Description: 操作行为日志模型
"""

#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class LogActionModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(LogActionModel, self).__init__(LogAction, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class LogAction:

    def __init__(self):
        super(LogAction, self).__init__()
        self.id = 0  # 自增主键
        self.module_code = ""  # 模块名称
        self.user_id = ""  # 用户id
        self.content = ""  # 日志内容
        self.record_time = 0  # 记录时间
        self.client_ip = ""  # 客户端IP

    @classmethod
    def get_field_list(self):
        return ['id', 'module_code', 'user_id', 'content', 'record_time', 'client_ip']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "cms_log_action_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: ChenXiaolei
:Date: 2020-12-07 19:13:46
:LastEditTime: 2020-12-07 19:14:06
:LastEditors: ChenXiaolei
:Description: 
"""
import random
class RandomUtil:
    @classmethod
    def get_random_switch_string(self, random_str, split_chars=","):
        """
        :description: 随机取得字符串
        :param trimChars：根据什么符号进行分割
        :return: 随机字符串
        :last_editors: HuangJingCan
        """
        if random_str == "":
            return ""
        random_list = [i for i in random_str.split(split_chars) if i != ""]
        return random.choice(random_list)


"""
:Author: HuangJingCan
:Date: 2020-03-24 19:48:05
:LastEditTime: 2025-08-26 14:57:55
:LastEditors: ChenXiaolei
:Description: 
"""
from seven_studio.handlers.studio_base import *
from seven_studio.libs.geetest import *

from seven_studio.models.db_models.user.user_info_model_ex import *
from seven_studio.models.db_models.role.role_power_model_ex import *
from seven_studio.models.db_models.role.role_user_model import *
from seven_studio.models.db_models.user.user_login_model import *
from seven_studio.models.seven_model import InvokeResult
from seven_studio.libs.file.upload import *


class CoreHandler(StudioBaseHandler):
    def get_async(self):
        result = "后台接口站"
        self.write(result)


class VerifyCodeHandler(StudioBaseHandler):
    def mask_phone_number(self, mobile):
        return mobile[:3] + mobile[3:-4].replace(mobile[3:-4], '*'*len(mobile[3:-4])) + mobile[-4:]

    @filter_check_params("account")
    def get_async(self):
        """
        :description: 判断用户是否配置手机号，前端配合显示手机验证码框
        :param account: 用户账号
        :return : 是否需要验证码
        :last_editors: ChenXiaolei
        """

        account = self.request_params["account"]
        
        user_info = UserInfoModelEx().get_dict(
            "Account=%s or Phone=%s", field="UserID,Phone", params=[account, account])
        
        if not user_info:
            return self.response_common("Check Password", "密码验证模式")
        
        login_key = user_info["UserID"].replace("-","")
        
        check_level = config.get_value("check_level", "safety")

        if check_level == "password":
            return self.response_common("Check Password", "密码验证模式",login_key)
        elif check_level in ["verify_code", "safety", "safety_strong"]:
            # 默认模式，白名单无需手机验证
            if check_level == "safety" and self.get_remote_ip() in self.get_group_ip():
                return self.response_common("Check Password", "密码验证模式",login_key)

        user_info = UserInfoModelEx().get_dict(
            "Account=%s or Phone=%s", field="Phone", params=[account, account])
        
        if user_info and user_info["Phone"]:
            if check_level == "verify_code":
                return self.response_common("Check VerifyCode", "验证码验证模式",login_key)
            elif check_level == "safety" or check_level == "safety_strong":
                return self.response_common("Check All", f"安全验证模式 ip:[{self.get_remote_ip()}]",login_key)

        return self.response_common("Check Password", "密码验证模式",login_key)

    @filter_check_params()
    def post_async(self):
        """
        :description: 发送验证码
        :param account: 用户账号
        :return : 发送结果
        :last_editors: ChenXiaolei
        """
        account = self.request_params.get("account", None)
        mobile = self.request_params.get("mobile", None)
        if account:
            # 如果account是11位的，就优先正则判断手机号
            if re.match(r'^1[3456789]\d{9}$', account):
                user_info = UserInfoModelEx().get_dict(
                    "Phone=%s", field="Account,Phone", params=[account])
            else:
                user_info = UserInfoModelEx().get_dict(
                    "Account=%s", field="Account,Phone", params=[account])

            if not user_info or not user_info["Phone"]:
                return self.response_common("Phone number not set", "用户未设置手机号")

            phone = user_info["Phone"]
        elif mobile:
            phone = mobile

        request_data = {
            "mobile": phone,
            "project_name": config.get_value("project_name")
        }

        resposne = HTTPHelper.post("https://ps.gao7.com/verify_code/sms",
                                   request_data, headers={'Content-Type': 'application/json'})

        if resposne:
            verify_json = json.loads(resposne.text)
            if verify_json["result"] == 0:
                return self.response_common("Send Fail", verify_json["desc"], data={"mobile": self.mask_phone_number(phone)})
            else:
                return self.response_common("0", "发送验证码成功", data={"mobile": self.mask_phone_number(phone)})


class GeetestCodeHandler(StudioBaseHandler):
    """
    :description: 获取极验证的验证码
    """

    def get_async(self):
        user_id = 'test'
        gt = GeetestLib(config.get_value("pc_geetest_id", "5993a5801d01dd43a07452be135a7381"),
                        config.get_value("pc_geetest_key", "e5bd10f056d92ee46d2ac7cd0356a979"))
        status = gt.pre_process(user_id, JSON_FORMAT=0, ip_address="127.0.0.1")
        if not status:
            status = 2
        response_str = gt.get_response_str()

        return self.response_json_success(response_str)


class LoginPlatformHandler(StudioBaseHandler):
    """
    :description: 登陆
    """

    def get_async(self):
        # 账号
        account = self.get_param("account")
        # 密码
        password = self.get_param("password")
        # 验证码，配置中需要开启
        verify_code = self.get_param("verify_code")
        # 极验证参数challenge
        challenge = self.get_param("challenge")
        # 极验证参数validate
        validate = self.get_param("validate")
        # 极验证参数seccode
        seccode = self.get_param("seccode")

        if account == "":
            return self.response_common("EmptyAccount", "对不起，请你输入账号")

        # 滑动验证码
        if config.get_value("is_captcha_check", True):
            if challenge == "" or validate == "" or seccode == "":
                return self.response_common("CaptchaError", "对不起，请先校验验证码")

            result = self.check_code(challenge, validate, seccode)
            if not result:
                return self.response_common("CaptchaError", "对不起，验证码验证失败")

        # 如果配置中未开启验证码校验，则必需输入密码，
        check_level = config.get_value("check_level", "safety")

        if check_level in ["safety", "safety_strong"]:
            if not password:
                return self.response_common("EmptyPassword", "请您输入密码")

            user_info = UserInfoModelEx().get_dict("Account=%s or Phone=%s", field="Phone", params=[account, account])
            
            if not user_info:
                return self.response_common("AccountNotExist", "用户不存在")

            # 默认模式，白名单无需手机验证
            if (check_level == "safety" and self.get_remote_ip() in self.get_group_ip()) or not user_info["Phone"]:
                invoke_result = self.login(account, password)
            else:
                if not verify_code:
                    return self.response_common("EmptyVerifyCode", "请输入验证码")

                invoke_result = self.login(account, password, verify_code=verify_code)
                
        elif check_level == "verify_code":
            # 验证码
            if not verify_code:
                return self.response_common("EmptyVerifyCode", "请输入验证码")
            invoke_result = self.login(account, verify_code=verify_code)
        else:
            # 密码
            invoke_result = self.login(account, password)

        # if check_level=="safety":
        #     if password == "":
        #         return self.response_common("EmptyPassword", "对不起，请您输入密码")
        #     invoke_result = self.login(account, password)
        # else:
        #     # 如果配置中开启验证码校验，则可通过verify_code校验登录，但是存在可通过初始密码登录的情况。
        #     if verify_code == "" and password=="":
        #         return self.response_common("EmptyPassword", "登录失败，请输入密码及验证码")
        #     elif password:
        #         invoke_result = self.login(account, password)
        #     elif verify_code:
        #         invoke_result = self.login(account, verify_code=verify_code )

        # invoke_result = self.login(account, password)

        if invoke_result.ResultCode == "0":
            invoke_result_user = self.check_login_user(
                invoke_result.Data['UserID'], invoke_result.Data['UserToken'])
            if invoke_result_user.ResultCode != "0":
                invoke_result = invoke_result_user

        return self.response_custom(invoke_result)

    def check_code(self, challenge="", validate="", seccode=""):
        """
        :description: 验证码校验
        :param challenge：极验证参数challenge
        :param validate：极验证参数validate
        :param seccode：极验证参数seccode
        :return: true or false
        :last_editors: HuangJingCan
        """
        gt = GeetestLib(config.get_value("pc_geetest_id", "5993a5801d01dd43a07452be135a7381"),
                        config.get_value("pc_geetest_key", "e5bd10f056d92ee46d2ac7cd0356a979"))
        result = gt.success_validate(
            challenge, validate, seccode, JSON_FORMAT=0)
        return result == 1

    def login(self, account="", password="", verify_code=""):
        """
        :description: 登录验证
        :param account：账号
        :param password：密码
        :param verify_code：验证码
        :return: invoke_result
        :last_editors: HuangJingCan
        """
        manage_context_key = config.get_value(
            "manage_context_key", "db_sevenstudio")
        base_manage_context_key = config.get_value(
            "base_manage_context_key", "db_sevenstudio")
        invoke_result = InvokeResult()
        user_info_model = UserInfoModel(base_manage_context_key)
        user_info = user_info_model.get_entity(
            "Account=%s or Phone=%s", params=[account, account])
        if not user_info:
            invoke_result.ResultCode = "NoExistAccount"
            invoke_result.ResultMessage = "用户名或密码错误"
            return invoke_result

        if user_info.FaildLoginCount > 4:
            invoke_result.ResultCode = "FaildLoginCountLimit"
            invoke_result.ResultMessage = "异常登录错误限制，请联系管理员解除限制"
            return invoke_result

        verify = True

        if password:
            verify = UserInfoModelEx().verify_password(
                password, user_info.Password, user_info.UserID)
            if not verify:
                user_info.FaildLoginCount += 1
                invoke_result.ResultCode = "ErrorPassword"
                invoke_result.ResultMessage = f"密码错误,尝试次数：{str(user_info.FaildLoginCount)}"
        if verify == True and verify_code:
            # 验证用户验证码
            resposne = HTTPHelper.get(
                f"https://ps.gao7.com/verify_code/sms?mobile={user_info.Phone}&project_name={config.get_value('project_name')}")

            if resposne:
                verify_json = json.loads(resposne.text)
                if verify_json["result"] == 0:
                    invoke_result.ResultCode = "VerifyCodeExpired"
                    invoke_result.ResultMessage = f"验证码已过期,请重新发送。"
                    verify = False
                elif verify_json["data"]["verify_code"] != verify_code:
                    user_info.FaildLoginCount += 1
                    invoke_result.ResultCode = "VerifyCodeError"
                    invoke_result.ResultMessage = f"验证码错误,尝试次数：{str(user_info.FaildLoginCount)}"
                    verify = False
                else:
                    verify = True
        if not verify:
            user_info_model.update_table("FaildLoginCount=%s", "UserID=%s", [
                                         user_info.FaildLoginCount, user_info.UserID])

            return invoke_result

        if user_info.IsLock == 1:
            invoke_result.ResultCode = "AccountLock"
            invoke_result.ResultMessage = "对不起你的帐号已经被锁定，请联系管理员解除限制"
            return invoke_result

        # is_super = user_info.IsSuper == 1

        if manage_context_key != base_manage_context_key:
            user_info_model_part = UserInfoModel(manage_context_key)
            user_info_curr = user_info_model_part.get_entity(
                "Account=%s", params=account)
            if not user_info_curr:
                invoke_result.ResultCode = "NoExistAccount"
                invoke_result.ResultMessage = "账号不存在"
                return invoke_result
            if user_info_curr.IsLock == 1:
                invoke_result.ResultCode = "AccountLock"
                invoke_result.ResultMessage = "对不起你的帐号已经被锁定，请联系管理员解除限制"
                return invoke_result

            # is_super = user_info_curr.IsSuper == 1 or user_info.IsSuper == 1

        # if is_platform and not is_super:
        #     role_user_list = RoleUserModel(manage_context_key).get_list("UserID=%s", params=user_info.UserID)
        #     if len(role_user_list) == 0:
        #         invoke_result.ResultCode = "AccountLock"
        #         invoke_result.ResultMessage = "对不起该账号没有平台管理权限"
        #         return invoke_result

        #     role_power_list = RolePowerModelEx(manage_context_key).get_role_power_list([i.RoleID for i in role_user_list])
        #     if not [i for i in role_power_list if i.MenuID == config.get_value("menu_id_platform", "03E5D2A0-DB59-47F6-8F10-1ACDEFE9BDDD")]:
        #         invoke_result.ResultCode = "AccountLock"
        #         invoke_result.ResultMessage = "对不起该账号没有平台管理权限"
        #         return invoke_result

        user_info.FaildLoginCount = 0
        user_info.LoginDate = TimeHelper.get_now_datetime()
        user_info.LoginIP = self.get_remote_ip()
        user_info_model.update_table("FaildLoginCount=%s,LoginDate=%s,LoginIP=%s", "UserID=%s", [
                                     user_info.FaildLoginCount, user_info.LoginDate, user_info.LoginIP, user_info.UserID])

        invoke_result.ResultCode = "0"
        invoke_result.ResultMessage = "调用成功"
        invoke_result.Data = self.set_user_info_login_status(
            user_info).__dict__

        return invoke_result

    def set_user_info_login_status(self, user_info):
        """
        :description: 登录状态设置
        :param user_info：当前登录用户信息
        :return: user_login
        :last_editors: HuangJingCan
        """
        user_login = UserLogin()
        user_login.UserID = user_info.UserID
        user_login.UserIDMD5 = CryptoHelper.md5_encrypt(user_info.UserID, config.get_value(
            "login_encrypt_key", "7C34A5212F7845CB85D4BBB589502D9B"))
        user_login.UserToken = UUIDHelper.get_uuid()
        user_login.ExpireTime = TimeHelper.add_hours_by_format_time(
            hour=config.get_value("login_expire", 10))

        self.login_cookie(user_login)

        return user_login


class LogoutHandler(StudioBaseHandler):
    """
    :description: 注销
    """

    def post_async(self):
        """
        :description: 注销用户
        :param {type} 
        :return: 
        :last_editors: HuangJingCan
        """
        self.logout(self.request_user_id())

        return self.response_json_success()


class UploadFilesHandler(StudioBaseHandler):
    """
    :description: 上传图片
    """

    def post_async(self):
        """
        :description: 上传图片
        :param resourceCode：resourceCode
        :param resourceCode：restrictCode
        :return: json
        :last_editors: HuangJingCan
        """
        # 获取参数
        resource_code = self.get_param("resourceCode")
        restrict_code = self.get_param("restrictCode")

        # 验证数据
        if resource_code == "":
            return self.response_common("ResourceCodeEmpty", "资源代码不能为空")
        if restrict_code == "":
            return self.response_common("RestrictCodeEmpty", "资源限制码不能为空")

        invoke_result = FileUpload(self.get_file_context_key()).upload(
            resource_code, restrict_code, self.request.files)

        if invoke_result.ResultCode == "0":
            return self.response_json_success(invoke_result.Data)
        else:
            return self.response_custom(invoke_result)




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class UserLoginModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(UserLoginModel, self).__init__(UserLogin, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class UserLogin:

    def __init__(self):
        super(UserLogin, self).__init__()
        self.UserID = ""  # 用户ID
        self.UserIDMD5 = ""  # 用户IDMD5
        self.UserToken = ""  # UserToken
        self.ExpireTime = "1900-01-01 00:00:00"  # 过期时间

    @classmethod
    def get_field_list(self):
        return ['UserID', 'UserIDMD5', 'UserToken', 'ExpireTime']
        
    @classmethod
    def get_primary_key(self):
        return "UserID"

    def __str__(self):
        return "cms_userlogin_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-04-22 14:32:40
:LastEditTime: 2020-12-09 19:12:39
:LastEditors: ChenXiaolei
:Description: 
"""
__all__ = ["core", "file", "power", "menu", "product", "settings"]



"""
:Author: ChenXiaolei
:Date: 2020-03-18 11:50:15
:LastEditTime: 2020-12-07 19:23:10
:LastEditors: ChenXiaolei
:Description: 极验证
"""
import sys
import random
import json
import requests
import time
from hashlib import md5

if sys.version_info >= (3,):
    xrange = range

VERSION = "3.0.0"


class GeetestLib(object):
    FN_CHALLENGE = "geetest_challenge"
    FN_VALIDATE = "geetest_validate"
    FN_SECCODE = "geetest_seccode"

    GT_STATUS_SESSION_KEY = "gt_server_status"

    API_URL = "http://api.geetest.com"
    REGISTER_HANDLER = "/register.php"
    VALIDATE_HANDLER = "/validate.php"
    JSON_FORMAT = False

    def __init__(self, captcha_id, private_key):
        self.private_key = private_key
        self.captcha_id = captcha_id
        self.sdk_version = VERSION
        self._response_str = ""

    def pre_process(self, user_id=None, new_captcha=1, JSON_FORMAT=1, client_type="web", ip_address=""):
        status, challenge = self._register(user_id, new_captcha, JSON_FORMAT, client_type, ip_address)
        self._response_str = self._make_response_format(status, challenge, new_captcha)
        return status

    def _register(self, user_id=None, new_captcha=1, JSON_FORMAT=1, client_type="web", ip_address=""):
        pri_responce = self._register_challenge(user_id, new_captcha, JSON_FORMAT, client_type, ip_address)
        if pri_responce:
            if JSON_FORMAT == 1:
                response_dic = json.loads(pri_responce)
                challenge = response_dic["challenge"]
            else:
                challenge = pri_responce
        else:
            challenge = " "
        if len(challenge) == 32:
            challenge = self._md5_encode("".join([challenge, self.private_key]))
            return 1, challenge
        else:
            return 0, self._make_fail_challenge()

    def get_response_str(self):
        return self._response_str

    def _make_fail_challenge(self):
        rnd1 = random.randint(0, 99)
        rnd2 = random.randint(0, 99)
        md5_str1 = self._md5_encode(str(rnd1))
        md5_str2 = self._md5_encode(str(rnd2))
        challenge = md5_str1 + md5_str2[0:2]
        return challenge

    def _make_response_format(self, success=1, challenge=None, new_captcha=1):
        if not challenge:
            challenge = self._make_fail_challenge()
        if new_captcha:
            string_format = json.dumps(
                {'success': success, 'gt': self.captcha_id, 'challenge': challenge, "new_captcha": True})
        else:
            string_format = json.dumps(
                {'success': success, 'gt': self.captcha_id, 'challenge': challenge, "new_captcha": False})
        return string_format

    def _register_challenge(self, user_id=None, new_captcha=1, JSON_FORMAT=1, client_type="web", ip_address=""):
        if user_id:
            register_url = "{api_url}{handler}?gt={captcha_ID}&user_id={user_id}&json_format={JSON_FORMAT}&client_type={client_type}&ip_address={ip_address}".format(
                api_url=self.API_URL, handler=self.REGISTER_HANDLER, captcha_ID=self.captcha_id, user_id=user_id,
                new_captcha=new_captcha, JSON_FORMAT=JSON_FORMAT, client_type=client_type, ip_address=ip_address)
        else:
            register_url = "{api_url}{handler}?gt={captcha_ID}&json_format={JSON_FORMAT}&client_type={client_type}&ip_address={ip_address}".format(
                api_url=self.API_URL, handler=self.REGISTER_HANDLER, captcha_ID=self.captcha_id,
                new_captcha=new_captcha, JSON_FORMAT=JSON_FORMAT, client_type=client_type, ip_address=ip_address)
        try:
            response = requests.get(register_url, timeout=2)
            if response.status_code == requests.codes.ok:
                res_string = response.text
            else:
                res_string = ""
        except:
            res_string = ""
        return res_string

    def success_validate(self, challenge, validate, seccode, user_id=None, gt=None, data='', userinfo='',
                         JSON_FORMAT=1):
        """
        正常模式的二次验证方式.向geetest server 请求验证结果.
        """
        if not self._check_para(challenge, validate, seccode):
            return 0
        if not self._check_result(challenge, validate):
            return 0
        validate_url = "{api_url}{handler}".format(
            api_url=self.API_URL, handler=self.VALIDATE_HANDLER)
        query = {
            "seccode": seccode,
            "sdk": ''.join(["python_", self.sdk_version]),
            "user_id": user_id,
            "data": data,
            "timestamp": time.time(),
            "challenge": challenge,
            "userinfo": userinfo,
            "captchaid": gt,
            "json_format": JSON_FORMAT
        }
        backinfo = self._post_values(validate_url, query)
        if JSON_FORMAT == 1:
            backinfo = json.loads(backinfo)
            backinfo = backinfo["seccode"]
        if backinfo == self._md5_encode(seccode):
            return 1
        else:
            return 0

    def _post_values(self, apiserver, data):
        response = requests.post(apiserver, data)
        return response.text

    def _check_result(self, origin, validate):
        encodeStr = self._md5_encode(self.private_key + "geetest" + origin)
        if validate == encodeStr:
            return True
        else:
            return False

    def failback_validate(self, challenge, validate, seccode):
        """
        failback模式的二次验证方式.在本地对轨迹进行简单的判断返回验证结果.
        """
        if not self._check_para(challenge, validate, seccode):
            return 0
        validate_result = self._failback_check_result(
            challenge, validate, )
        return validate_result

    def _failback_check_result(self, challenge, validate):
        encodeStr = self._md5_encode(challenge)
        if validate == encodeStr:
            return True
        else:
            return False

    def _check_para(self, challenge, validate, seccode):
        return (bool(challenge.strip()) and bool(validate.strip()) and bool(seccode.strip()))

    def _md5_encode(self, values):
        if type(values) == str:
            values = values.encode()
        m = md5(values)
        return m.hexdigest()



# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-10-20 10:15:03
:LastEditTime: 2020-12-09 14:45:37
:LastEditors: ChenXiaolei
:Description: 自定义实体
"""

from seven_studio.models.enum import ButtonPlace


class PowerButtonDto():
    """
    :description: 权限按钮
    """
    def __init__(self):
        self.ID = ""
        self.Title = ""
        self.Icon = ""
        self.ViewPath = ""
        self.ApiPath = ""
        self.Path = ""
        self.CommandName = ""
        self.CommandParms = ""
        self.ShowCondition = ""
        self.ButtonColor = ""
        self.ButtonPlace = ButtonPlace.Top


class PowerMenuInfoDto():
    """
    :description: 权限栏目
    """
    def __init__(self):
        self.MenuID = ""
        self.MenuIcon = ""
        self.MenuName = ""
        self.ViewPath = ""
        self.ApiPath = ""
        self.Path = ""
        self.IsHidden = False
        self.MenuItemDtoList = []
        self.MenuButtonDtoList = []


class RoleUserDto():
    """
    :description: 角色用户
    """
    def __init__(self):
        self.RoleID = ""
        self.RoleName = ""
        self.Summary = ""
        self.ModifyDate = ""
        self.ModifyUser = ""
        self.RoleUserIds = []
        self.RoleMenuIds = []
        self.IsAdd=True

    @classmethod
    def get_field_list(self):
        return ['RoleID', 'RoleName', 'Summary', 'ModifyDate', 'ModifyUser', 'RoleUserIds', 'RoleMenuIds', 'IsAdd']


class UserRoleDto():
    """
    :description: 用户角色
    """
    def __init__(self):
        self.UserID = ""
        self.IsSuper = 0
        self.Account = ""
        self.Email = ""
        self.Phone = ""
        self.UserName = ""
        self.NickName = ""
        self.JobNo = ""
        self.Avatar = ""
        self.IsLock = 0
        self.FaildLoginCount = 0
        self.ChiefUserName = ""
        self.LoginDate = ""
        self.UserRoleIds = []
        self.UserProductIds = []
        self.IsAdd = True

    @classmethod
    def get_field_list(self):
        return ['UserID', 'IsSuper', 'Account', 'Email', 'Phone', 'UserName', 'NickName', 'JobNo', 'Avatar', 'IsLock', 'FaildLoginCount', 'ChiefUserName', 'LoginDate', 'UserRoleIds', 'UserProductIds', 'IsAdd']


class LogAppDto():
    """
    :description: 日志
    """
    def __init__(self):
        self.AppID = 0
        self.AppCode = ""
        self.AppName = ""
        self.ParentID = 0
        self.IDPath = ""
        self.ErrorCount = 0
        self.FatalCount = 0
        self.NoticePhone = ""
        self.NoticeInterval = 0
        self.IsNotice = 0
        self.LogStoreInfo = ""
        self.NoticeCheckInfo = ""
        self.ChildList = []

    @classmethod
    def get_field_list(self):
        return ['AppID', 'AppCode', 'AppName', 'ParentID', 'IDPath', 'ErrorCount', 'FatalCount', 'NoticePhone', 'NoticeInterval', 'IsNotice', 'LogStoreInfo', 'NoticeCheckInfo', 'ChildList']



# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-02 15:17:41
:LastEditTime: 2020-05-02 15:32:51
:LastEditors: HuangJingCan
:Description: 自定义实体
"""


class InvokeResult():
    """
    :description: 接口返回实体
    :param {type} 
    :return: InvokeResult
    :last_editors: HuangJingCan
    """
    def __init__(self):
        self.ResultCode = "0"
        self.ResultMessage = "调用成功"
        self.Data = None


class FileUploadInfo():
    """
    :description: 文件上传信息实体
    :param {type} 
    :return: FileUploadInfo
    :last_editors: HuangJingCan
    """
    def __init__(self):
        # 检查值
        self.Md5Value = ""
        # 上传路经
        self.ResourcePath = ""
        # 原文件名
        self.OriginalName = ""
        # 文件路经
        self.FilePath = ""
        # 图片宽度
        self.ImageWidth = 0
        # 图片高度
        self.ImageHeight = 0


class PageInfo():
    """
    :description: 分页列表实体
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    def __init__(self):
        # 当前索引号
        self.PageIndex = 0
        # 页大小
        self.PageSize = 0
        # 总记录数
        self.RecordCount = 0
        # 数据
        self.Data = None

    def get_entity_by_page_info(self, page_info):
        # 页数
        page_info.PageCount = page_info.RecordCount / page_info.PageSize + 1
        if page_info.PageSize == 0:
            page_info.PageCount = 0
        if page_info.RecordCount % page_info.PageSize == 0:
            page_info.PageCount = page_info.RecordCount / page_info.PageSize
        page_info.PageCount = int(page_info.PageCount)
        # 当前页号
        page_info.PageNo = page_info.PageIndex + 1
        # 上一页索引
        page_info.PreviousIndex = page_info.PageIndex - 1 if page_info.PageIndex > 0 else 0
        # 下一页索引
        page_info.NextIndex = page_info.PageIndex + 1
        if page_info.PageCount == 0:
            page_info.NextIndex = 0
        if page_info.PageNo >= page_info.PageCount:
            page_info.NextIndex = page_info.PageIndex
        # 是否下一页
        page_info.IsNext = True
        if page_info.PageCount == 0:
            page_info.IsNext = False
        if page_info.PageNo >= page_info.PageCount:
            page_info.IsNext = False
        # 是否上一页
        page_info.IsPrevious = True
        if page_info.PageIndex == 0:
            page_info.IsPrevious = False
        # 总记录数int
        page_info.RecordCountInt = page_info.RecordCount
        # 扩展数据
        page_info.ExtendData = None

        return page_info


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-04-22 14:32:40
:LastEditTime: 2020-05-03 15:40:35
:LastEditors: HuangJingCan
:Description: 枚举类
"""

from enum import Enum, unique


class ButtonType(Enum):
    """
    :description: 按钮类型
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    # 新增
    Add = 1
    # 修改
    Modify = 2
    # 删除
    Delete = 3
    # 保存
    Save = 4
    # 返回
    Back = 5
    # 查询
    Search = 6
    # 详细
    View = 7
    # 发布
    Release = 8
    # 取消发布
    UnRelease = 9


class ButtonPlace(Enum):
    """
    :description: 按钮位置
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    Top = 1  # 顶部
    List = 2  # 列表


class QueryMethod(Enum):
    """
    :description: 查询方式
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    # 等于
    Equal = "Equal"
    # 大于
    GreaterThan = "GreaterThan"
    # 大于等于
    GreaterThanOrEqual = "GreaterThanOrEqual"
    # 小于
    LessThan = "LessThan"
    # 小于等于
    LessThanOrEqual = "LessThanOrEqual"
    # 不等于
    NotEqual = "NotEqual"
    # LIKE '值%'
    StartsWith = "StartsWith"
    # LIKE '值%'
    EndsWith = "EndsWith"
    # LIKE '%值%'
    Contains = "Contains"
    # 多值查询
    ORLike = "ORLike"


class QueryDataType(Enum):
    """
    :description: 查询数据类型
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    # 字符串型
    String = "String"
    # 数字型
    Int = "Int"
    # 时间
    Date = "Date"


class QuerySortType(Enum):
    """
    :description: 排序类型
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    # 降序
    Desc = "Desc"
    # 升序
    Asc = "Asc"


class AccessModeCodeType(Enum):
    """
    :description: 访问方式代码
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    # 虚拟访问方式
    VirtualAccess = 0
    # 虚拟原文件访问方式
    VirtualOriginalAccess = 1


class PathFormatCodeType(Enum):
    """
    :description: 路径格式代码
    :param {type} 
    :return: 
    :last_editors: HuangJingCan
    """
    # 按创建日期组织
    ByDate = 0
    # 按创建日期加小时组织
    ByDateAndHour = 1
    # 按唯一标识分组组织
    ByID = 2
    # 不分组
    ByNone = 3



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class MenuCoteModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(MenuCoteModel, self).__init__(MenuCote, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class MenuCote:

    def __init__(self):
        super(MenuCote, self).__init__()
        self.MenuCoteID = 0  # 
        self.CoteTitle = ""  # 栏目名称
        self.CoteTableName = ""  # 栏目表名
        self.IDName = ""  # 主键名
        self.Name = ""  # 显示名称
        self.ParentIDName = ""  # 父节点标识
        self.IDPathName = ""  # ID路经名称
        self.ConnectionStringName = ""  # 链接字符串
        self.RootIDValue = ""  # 根节点ID值
        self.IDDataType = 0  # ID类型1整型2字符串
        self.IsParentUrl = 0  # 是否父节点链接
        self.SortExpression = ""  # 排序
        self.Condtion = ""  # 条件

    @classmethod
    def get_field_list(self):
        return ['MenuCoteID', 'CoteTitle', 'CoteTableName', 'IDName', 'Name', 'ParentIDName', 'IDPathName', 'ConnectionStringName', 'RootIDValue', 'IDDataType', 'IsParentUrl', 'SortExpression', 'Condtion']
        
    @classmethod
    def get_primary_key(self):
        return "MenuCoteID"

    def __str__(self):
        return "cms_menucote_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class FileRestrictModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(FileRestrictModel, self).__init__(FileRestrict, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class FileRestrict:

    def __init__(self):
        super(FileRestrict, self).__init__()
        self.FileRestrictID = ""  # 文件限制标识
        self.FileStoragePathID = ""  # 存储路经标识
        self.FileResourceID = ""  # 文件资源标识
        self.AccessModeCodeType = 0  # 文件访问方式
        self.PathFormatCodeType = 0  # 目录存储格式
        self.ResourceCode = ""  # 资源代码
        self.RestrictName = ""  # 限制名称
        self.RestrictCode = ""  # 限制码
        self.FileType = 0  # 1文件2图片3flash4mid
        self.FileExtension = ""  # 文件扩展名
        self.FileMaxSize = 0  # 大小限制单位(K)0不限制
        self.IsReturnSize = 0  # 是否返回尺寸
        self.IsMd5 = 0  # 是否Md5
        self.IsHistory = 0  # 是否记录文件记录
        self.IsWaterMark = 0  # 是否创建水印
        self.IsFormatJpeg = 0  # 是否格式化成Jpeg
        self.WatermarkText = ""  # 水印文字
        self.HorizontalAlign = 0  # 水平位置
        self.VerticalAlign = 0  # 垂直位置
        self.ImageWidth = 0  # 图片宽度
        self.ImageHeight = 0  # 图片高度
        self.QualityValue = 0  # 质量压缩
        self.WatermarkType = 0  # 水印类型
        self.WaterImageID = ""  # 水印标识

    @classmethod
    def get_field_list(self):
        return ['FileRestrictID', 'FileStoragePathID', 'FileResourceID', 'AccessModeCodeType', 'PathFormatCodeType', 'ResourceCode', 'RestrictName', 'RestrictCode', 'FileType', 'FileExtension', 'FileMaxSize', 'IsReturnSize', 'IsMd5', 'IsHistory', 'IsWaterMark', 'IsFormatJpeg', 'WatermarkText', 'HorizontalAlign', 'VerticalAlign', 'ImageWidth', 'ImageHeight', 'QualityValue', 'WatermarkType', 'WaterImageID']
        
    @classmethod
    def get_primary_key(self):
        return "FileRestrictID"

    def __str__(self):
        return "cms_filerestrict_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class FileStoragePathModel(BaseModel):
    def __init__(self, db_connect_key='db_sevenstudio', sub_table=None, db_transaction=None):
        super(FileStoragePathModel, self).__init__(FileStoragePath, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction

    #方法扩展请继承此类
    
class FileStoragePath:

    def __init__(self):
        super(FileStoragePath, self).__init__()
        self.FileStoragePathID = ""  # 存储标识
        self.StoragePathName = ""  # 存储名称
        self.StorageTypeID = 0  # 存储类型1本地存储2FTP3文件系统
        self.VirtualName = ""  # 虚目录
        self.StoragePath = ""  # 存储地址
        self.IPAddress = ""  # IP
        self.Account = ""  # 帐号
        self.Password = ""  # 密码
        self.Port = ""  # 端口
        self.StorageConfig = ""  # 配置文件

    @classmethod
    def get_field_list(self):
        return ['FileStoragePathID', 'StoragePathName', 'StorageTypeID', 'VirtualName', 'StoragePath', 'IPAddress', 'Account', 'Password', 'Port', 'StorageConfig']
        
    @classmethod
    def get_primary_key(self):
        return "FileStoragePathID"

    def __str__(self):
        return "cms_filestoragepath_tb"
    